@@ -48,6 +48,7 @@
 #include <QStringList>
 
 #include <qtextcodec.h>
+#include "rs_debug.h"
 
 /**
  * Default constructor.
@@ -138,7 +139,7 @@ bool RS_FilterDXF::fileImport(RS_Graphic& g, const QString& file, RS2::FormatTyp
 }
 
 /*
- * get teh encoding of the DXF files,
+ * get the encoding of the DXF files,
  * Acad versions >= 2007 are UTF-8, others in ANSI_1252
  */
 QString RS_FilterDXF::getDXFEncoding() {
@@ -467,7 +468,7 @@ void RS_FilterDXF::addInsert(const DL_InsertData& data) {
                     RS2::NoUpdate);
     RS_Insert* entity = new RS_Insert(currentContainer, d);
     setEntityAttributes(entity, attributes);
-    RS_DEBUG->print("  id: %d", entity->getId());
+    RS_DEBUG->print("  id: %lu", entity->getId());
     //entity->update();
     currentContainer->addEntity(entity);
 }
@@ -682,7 +683,7 @@ RS_DimensionData RS_FilterDXF::convDimensionData(
 
     // middlepoint of text can be 0/0 which is considered to be invalid (!):
     //  0/0 because older QCad versions save the middle of the text as 0/0
-    //  althought they didn't suport saving of the middle of the text.
+    //  although they didn't support saving of the middle of the text.
     if (fabs(data.mpx)<1.0e-6 && fabs(data.mpy)<1.0e-6) {
         midP = RS_Vector(false);
     }
@@ -2416,7 +2417,7 @@ void RS_FilterDXF::writeEntityContainer(DL_WriterA& dw, RS_EntityContainer* con,
 
 
 /**
- * Writes the atomic entities of the given cotnainer to the file.
+ * Writes the atomic entities of the given container to the file.
  */
 void RS_FilterDXF::writeAtomicEntities(DL_WriterA& dw, RS_EntityContainer* c,
                                        const DL_Attributes& attrib,
@@ -3275,7 +3276,7 @@ RS2::Unit RS_FilterDXF::numberToUnit(int num) {
 
 
 /**
- * Converst a unit enum into a DXF unit number e.g. for INSUNITS.
+ * Converts a unit enum into a DXF unit number e.g. for INSUNITS.
  */
 int RS_FilterDXF::unitToNumber(RS2::Unit unit) {
     switch (unit) {
